@@ -1,5 +1,4 @@
 from . import __meta__
-
-from .core import Experiment
+from .core import Experiment, run_fissa
 
 __version__ = __meta__.version
